#!/usr/bin/env python
#
# Script used to check zuul pipelines
# Type of check
#  - wait_time  - return longest time which job spend in queue
#  - wait_count - return number of jobs which wait for
#                 execution in queue

import json
import urllib2
import time
import argparse

parser = argparse.ArgumentParser(
    description='Zabbix tool to get pipeline informations from zuul.'
)
parser.add_argument('pipeline_name', help='pipeline name to check')
parser.add_argument(
    "-t", help="Type of data to return",
    required=True, choices=['wait_time', 'wait_count']
)
parser.add_argument("--host", help="Zabbix host name", default='localhost')
parser.add_argument(
    "--all",
    help="Count data for all pipelines",
    action="store_true"
)
args = parser.parse_args()

time_now = time.time()

# get data from zuul
json_url = 'http://%s/status.json' % args.host
resp = urllib2.urlopen(json_url)
data = json.loads(resp.read())


def check_queue(queue_data, value):
    """
    Check queue and return requested value
    """
    wait_count = 0
    wait_time = 0

    # check group of jobs
    for jobgroup in queue_data:
        for jobgroup2 in jobgroup:
            # check job
            for job in jobgroup2['jobs']:
                # Conut jobs without start time
                if not job['start_time']:
                    wait_count += 1
                    time_enqueue = float(jobgroup2['enqueue_time']/1000)
                    time_in_queue = int(time_now - time_enqueue)
                    if time_in_queue > wait_time:
                        wait_time = time_in_queue

    if args.t == 'wait_count':
        return wait_count
    if args.t == 'wait_time':
        return wait_time

test_value = 0
for pipeline in data['pipelines']:
    # Skip unchecked pipelines
    if not pipeline['name'] == args.pipeline_name and not args.all:
        continue

    # Looking for queues with jobs
    for queue in pipeline['change_queues']:
        if len(queue['heads']) > 0:
            test_value += check_queue(queue['heads'], args.t)

print test_value
